@@ -1,5 +1,5 @@
 package experimental;
-$experimental::VERSION = '0.018';
+$experimental::VERSION = '0.021';
 use strict;
 use warnings;
 use version ();
@@ -23,8 +23,10 @@ my %min_version = (
 	bitwise         => '5.22.0',
 	const_attr      => '5.22.0',
 	current_sub     => '5.16.0',
+	declared_refs   => '5.26.0',
 	evalbytes       => '5.16.0',
 	fc              => '5.16.0',
+	isa             => '5.31.7',
 	lexical_topic   => '5.10.0',
 	lexical_subs    => '5.18.0',
 	postderef       => '5.20.0',
@@ -39,17 +41,19 @@ my %min_version = (
 	unicode_eval    => '5.16.0',
 	unicode_strings => '5.12.0',
 );
-my %max_version = (
+my %removed_in_version = (
+	array_base      => '5.29.4',
 	autoderef       => '5.23.1',
 	lexical_topic   => '5.23.4',
 );
 
 $_ = version->new($_) for values %min_version;
-$_ = version->new($_) for values %max_version;
+$_ = version->new($_) for values %removed_in_version;
 
 my %additional = (
-	postderef  => ['postderef_qq'],
-	switch     => ['smartmatch'],
+	postderef     => ['postderef_qq'],
+	switch        => ['smartmatch'],
+	declared_refs => ['refaliasing'],
 );
 
 sub _enable {
@@ -75,8 +79,8 @@ sub _enable {
 		}
 		croak "Need perl $stable or later for feature $pragma";
 	}
-	elsif ($] >= ($max_version{$pragma} || 7)) {
-		croak "Experimental feature $pragma has been removed from perl in version $max_version{$pragma}";
+	elsif ($] >= ($removed_in_version{$pragma} || 7)) {
+		croak "Experimental feature $pragma has been removed from perl in version $removed_in_version{$pragma}";
 	}
 }
 
@@ -130,7 +134,7 @@ experimental - Experimental features made easy
 
 =head1 VERSION
 
-version 0.018
+version 0.021
 
 =head1 SYNOPSIS
 
@@ -179,6 +183,14 @@ This was added in perl 5.22.0.
 
 This was added in perl 5.22.0.
 
+=item * C<declared_refs> - enables aliasing via assignment to references
+
+This was added in perl 5.26.0.
+
+=item * C<isa> - allow the use of the C<isa> infix operator
+
+This was added in perl 5.32.0.
+
 =item * C<lexical_topic> - allow the use of lexical C<$_> via C<my $_>.
 
 This was added in perl 5.10.0 and removed in perl 5.23.4.
@@ -187,10 +199,13 @@ This was added in perl 5.10.0 and removed in perl 5.23.4.
 
 This was added in 5.18.0.
 
-=item * C<postderef> - allow the use of postfix dereferencing expressions,
-including in interpolating strings
+=item * C<postderef> - allow the use of postfix dereferencing expressions
 
-This was added in perl 5.20.0.
+This was added in perl 5.20.0, and became non-experimental (and always enabled) in 5.24.0.
+
+=item * C<postderef_qq> - allow the use of postfix dereferencing expressions inside interpolating strings
+
+This was added in perl 5.20.0, and became non-experimental (and always enabled) in 5.24.0.
 
 =item * C<re_strict> - enables strict mode in regular expressions
 
@@ -250,7 +265,7 @@ be guaranteed in any way.
 
 =head1 SEE ALSO
 
-L<perlexperimental|perlexperimental> contains more information about experimental features.
+L<perlexperiment|perlexperiment> contains more information about experimental features.
 
 =head1 AUTHOR
 
